<?php

namespace KnitPay\Gateways\Omnipay;

use Pronamic\WordPress\Pay\AbstractGatewayIntegration;
use Pronamic\WordPress\Pay\Core\IntegrationModeTrait;
use Pronamic\WordPress\Pay\Payments\Payment;
use Omnipay\Omnipay;

/**
 * Title: Omnipay Integration
 * Copyright: 2020-2023 Knit Pay
 *
 * @author  Knit Pay
 * @version 8.72.0.0
 * @since   8.72.0.0
 */
class Integration extends AbstractGatewayIntegration {
	use IntegrationModeTrait;
	
	/**
	 * Construct Omnitpay integration.
	 *
	 * @param array $args Arguments.
	 */
	public function __construct( $args = [] ) {
		$this->omnipay_gateway = Omnipay::create( $args['omnipay_class'] );

		$args = wp_parse_args(
			$args,
			[
				'name' => $this->omnipay_gateway->getName(),
			]
		);

		parent::__construct( $args );
	}

	/**
	 * Get settings fields.
	 *
	 * @return array
	 */
	public function get_settings_fields() {
		$fields = [];
		
		$params = $this->get_omnipay_params();
		
		foreach ( $params as $parm => $val ) {
			switch ( getType( $val ) ) {
				case 'boolean':
					$type = 'checkbox';
					break;
				case 'string':
				default:
					$type = 'text';
					break;
			}
			$fields[] = [
				'section'  => 'general',
				'filter'   => FILTER_SANITIZE_STRING,
				'meta_key' => '_pronamic_gateway_' . $parm,
				'title'    => $parm,
				'label'    => $parm,
				'type'     => $type,
				'classes'  => [ 'regular-text', 'code' ],
				'default'  => $val,

			];
		}
		
		return $fields;
	}

	public function get_config( $post_id ) {
		$config = [];

		$params = $this->get_omnipay_params();

		foreach ( $params as $parm => $val ) {
			$config[ $parm ] = $this->get_meta( $post_id, $parm );
		}

		return $config;
	}

	/**
	 * Get gateway.
	 *
	 * @param int $config_id Post ID.
	 * @return Gateway
	 */
	public function get_gateway( $config_id ) {
		$config  = $this->get_config( $config_id );
		$gateway = new Gateway();

		$this->omnipay_gateway->initialize( $config );

		$mode = Gateway::MODE_LIVE;
		if ( $config['testMode'] ) {
			$mode = Gateway::MODE_TEST;
		}

		$this->set_mode( $mode );
		$gateway->set_mode( $mode );
		$gateway->init( $this->omnipay_gateway );

		return $gateway;
	}
	
	private function get_omnipay_params() {
		$params             = $this->omnipay_gateway->getParameters();
		$params['testMode'] = false;
		return $params;
	}
}
